==> monodevelop_2.0%2Bdfsg.orig.tar.gz: monodevelop-2.0/src/addins/MonoDevelop.GtkCore/MonoDevelop.GtkCore.NodeBuilders/WindowsFolder.cs <==
//
// WindowsFolder.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Projects;
using MonoDevelop.GtkCore.GuiBuilder;

namespace MonoDevelop.GtkCore.NodeBuilders
{
	class WindowsFolder
	{
		Project project;
		
		public event EventHandler Changed;
		
		public WindowsFolder (Project project)
		{
			this.project = project;
			GtkDesignInfo info = GtkDesignInfo.FromProject (project);
			
			info.GuiBuilderProject.Changed += OnUpdateFiles;
		}
		
		public void Dispose ()
		{
			GtkDesignInfo info = GtkDesignInfo.FromProject (project);
			info.GuiBuilderProject.Changed -= OnUpdateFiles;
		}
		
		void OnUpdateFiles (object s, EventArgs args)
		{
			if (Changed != null) Changed (this, EventArgs.Empty);
		}
		
		public Project Project {
			get { return project; }
		}
	}
}

==> monodevelop_3.0.2%2Bdfsg.orig.tar.gz: monodevelop-3.0.2/src/addins/MonoDevelop.GtkCore/MonoDevelop.GtkCore.NodeBuilders/WindowsFolder.cs <==
//
// WindowsFolder.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Projects;
using MonoDevelop.GtkCore.GuiBuilder;

namespace MonoDevelop.GtkCore.NodeBuilders
{
	class WindowsFolder
	{
		Project project;
		GuiBuilderProject gproject;
		
		public event EventHandler Changed;
		
		public WindowsFolder (Project project)
		{
			this.project = project;
			GtkDesignInfo info = GtkDesignInfo.FromProject (project);
			
			gproject = info.GuiBuilderProject;
			gproject.Changed += OnUpdateFiles;
		}
		
		public void Dispose ()
		{
			gproject.Changed -= OnUpdateFiles;
		}
		
		void OnUpdateFiles (object s, EventArgs args)
		{
			if (Changed != null) Changed (this, EventArgs.Empty);
		}
		
		public Project Project {
			get { return project; }
		}

		public override bool Equals (object obj)
		{
			WindowsFolder wf = obj as WindowsFolder;
			return wf != null && wf.project == project;
		}

		public override int GetHashCode ( )
		{
			unchecked {
				return project.GetHashCode () * 234;
			}
		}
	}
}
